library(ggplot2)


data = read.table("results/results0.25",
  header = F, # file does not contain a header (`F` is short for `FALSE`), so we must manually specify column names                    
  sep = "\t", # file is tab-delimited        
  col.names = c("runtime", "precision", "method", "parameters") # column names
)
data$runtime <- data$runtime/1000
data$method <- factor(data$method, levels = c("CI1", "CI2", "J4", "T3b", "", "N2.8", "RDTL"))
pp <- ggplot(data, aes(method, precision, x = method, y = precision, scale = "count", group=method)) + coord_cartesian(ylim=c(0.0,1.0)) + ylab("precision") + geom_violin() + geom_vline(xintercept = 5, linetype = "dashed") + stat_summary(fun.y=mean, geom="point") + facet_grid(~ parameters) + theme_bw()
ggsave(pp, file = "resultsPrecision25.eps", width = 10, height = 3.5)
pp <- ggplot(data, aes(method, precision, x = method, y = precision, scale = "count", group=method)) + coord_cartesian(ylim=c(0.0,1.0)) + ylab("precision") + geom_boxplot() + geom_vline(xintercept = 5, linetype = "dashed") + facet_grid(~ parameters) + theme_bw()
ggsave(pp, file = "resultsPrecision25B.eps", width = 10, height = 3.5)
pr <- ggplot(data, aes(method, runtime, x = method, y = runtime, group=method)) + coord_cartesian(ylim=c(0,25)) + geom_boxplot() + geom_vline(xintercept = 5, linetype = "dashed") + facet_grid(~ parameters) + theme_bw()
ggsave(pr, file = "resultsRuntime25.eps", width = 10, height = 3.5)


data = read.table("results/results0.50",
  header = F, # file does not contain a header (`F` is short for `FALSE`), so we must manually specify column names                    
  sep = "\t", # file is tab-delimited        
  col.names = c("runtime", "precision", "method", "parameters") # column names
)
data$runtime <- data$runtime/1000
data$method <- factor(data$method, levels = c("CI1", "CI2", "J4", "T3b", "", "N2.8", "RDTL"))
pp <- ggplot(data, aes(method, precision, x = method, y = precision, scale = "count", group=method)) + coord_cartesian(ylim=c(0.0,1.0)) + ylab("precision") + geom_violin() + geom_vline(xintercept = 5, linetype = "dashed") + stat_summary(fun.y=mean, geom="point") + facet_grid(~ parameters) + theme_bw()
ggsave(pp, file = "resultsPrecision50.eps", width = 10, height = 3.5)
pp <- ggplot(data, aes(method, precision, x = method, y = precision, scale = "count", group=method)) + coord_cartesian(ylim=c(0.0,1.0)) + ylab("precision") + geom_boxplot() + geom_vline(xintercept = 5, linetype = "dashed") + facet_grid(~ parameters) + theme_bw()
ggsave(pp, file = "resultsPrecision50B.eps", width = 10, height = 3.5)
pr <- ggplot(data, aes(method, runtime, x = method, y = runtime, group=method)) + coord_cartesian(ylim=c(0,25)) + geom_boxplot() + geom_vline(xintercept = 5, linetype = "dashed") + facet_grid(~ parameters) + theme_bw()
ggsave(pr, file = "resultsRuntime50.eps", width = 10, height = 3.5)


data = read.table("results/results0.75",
  header = F, # file does not contain a header (`F` is short for `FALSE`), so we must manually specify column names                    
  sep = "\t", # file is tab-delimited        
  col.names = c("runtime", "precision", "method", "parameters") # column names
)
data$runtime <- data$runtime/1000
data$method <- factor(data$method, levels = c("CI1", "CI2", "J4", "T3b", "", "N2.8", "RDTL"))
pp <- ggplot(data, aes(method, precision, x = method, y = precision, scale = "count", group=method)) + coord_cartesian(ylim=c(0.0,1.0)) + ylab("precision") + geom_violin() + geom_vline(xintercept = 5, linetype = "dashed") + stat_summary(fun.y=mean, geom="point") + facet_grid(~ parameters) + theme_bw()
ggsave(pp, file = "resultsPrecision75.eps", width = 10, height = 3.5)
pp <- ggplot(data, aes(method, precision, x = method, y = precision, scale = "count", group=method)) + coord_cartesian(ylim=c(0.0,1.0)) + ylab("precision") + geom_boxplot() + geom_vline(xintercept = 5, linetype = "dashed") + facet_grid(~ parameters) + theme_bw()
ggsave(pp, file = "resultsPrecision75B.eps", width = 10, height = 3.5)
pr <- ggplot(data, aes(method, runtime, x = method, y = runtime, group=method)) + coord_cartesian(ylim=c(0,25)) + geom_boxplot() + geom_vline(xintercept = 5, linetype = "dashed") + facet_grid(~ parameters) + theme_bw()
ggsave(pr, file = "resultsRuntime75.eps", width = 10, height = 3.5)
